@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -31,16 +31,12 @@ C<Object::Pad> - a simple syntax for lexical slot-based objects
    use Object::Pad;
 
    class Point {
-      has $x;
-      has $y;
+      has $x = 0;
+      has $y = 0;
 
-      method CREATE {
-         $x = $y = 0;
-      }
-
-      method move {
-         $x += shift;
-         $y += shift;
+      method move($dX, $dY) {
+         $x += $dX;
+         $y += $dY;
       }
 
       method describe {
@@ -66,7 +62,7 @@ private variables that look like lexicals as object member fields.
 
 Behaves similarly to the C<package> keyword, but provides a package that
 defines a new class. Such a class provides an automatic constructor method
-called C<new>, which will invoke the class's C<CREATE> method if it exists.
+called C<new>, which will invoke the class's C<BUILDALL> method if it exists.
 
 A single superclass is supported by the keyword C<extends>
 
@@ -79,6 +75,7 @@ The superclass must also be implemented by C<Object::Pad>.
 =head2 has
 
    has $var;
+   has $var = CONST;
    has @var;
    has %var;
 
@@ -93,6 +90,12 @@ Member fields are private to a class. They are not visible to users of the
 class, nor to subclasses. In order to provide access to them a class may wish
 to use L</method> to create an accessor.
 
+A scalar slot may provide a expression that gives an initialisation value,
+which will be assigned into the slot of every instance during the constructor
+before C<BUILDALL> is invoked. For ease-of-implementation reasons this
+expression must currently be a compiletime constant, but it is hoped that a
+future version will relax this restriction and allow runtime-computed values.
+
 =head2 method
 
    method NAME {
@@ -146,6 +149,17 @@ C<class> block acts as if the following pragmata are in effect:
    no indirect ':fatal';
    use feature 'signatures';
 
+This list may be extended in subsequent versions to add further restrictions
+and should not be considered exhaustive.
+
+Further additions will only be ones that remove "discouraged" or deprecated
+language features with the overall goal of enforcing a more clean modern style
+within the body. As long as you write code that is in a clean, modern style
+(and I fully accept that this wording is vague and subjective) you should not
+find any new restrictions to be majorly problematic. Either the code will
+continue to run unaffected, or you may have to make some small alterations to
+bring it into a conforming style.
+
 =cut
 
 sub import
@@ -169,6 +183,18 @@ sub import_into
    croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 }
 
+sub Object::Pad::_base::new
+{
+   my $class = shift;
+
+   my $self = bless [], $class;
+   $self->INITSLOTS;
+
+   $self->BUILDALL( @_ ) if $self->can( "BUILDALL" );
+
+   return $self;
+}
+
 =head1 TODO
 
 =over 4
@@ -199,9 +225,9 @@ to improve method-enter performance.
 
 Some extensions of the C<has> syntax:
 
-Default expressions
+Non-constant default expressions
 
-   has $var = DEFAULT;
+   has $var = EXPR;
 
 A way to request generated accessors - ro or rw.
 
